///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
// bug fixed in diag() thanks to Aymen Laadhari
#include "rheolef.h"
using namespace rheolef;
using namespace std;
int main(int argc, char**argv) {
  environment rheolef ( argc , argv );
  geo omega (argv[1]);
  Float tol = (argc > 2) ? atof(argv[2]) : 1e-10;
  space Xh (omega, "P1");
  field one (Xh, 1);
  form dm (Xh, Xh, "lumped_mass");
  field dh = diag(dm);
  field inv_dh = lazy_interpolate (Xh, 1./dh);
  form inv_dm = diag(inv_dh);
  field eh = (inv_dm*dm)*one - one;
  Float err = dm (eh, eh);
  derr << "err = " << err << endl;
  return (err < tol) ? 0 : 1;
}
